# spkan - Sparse Convolutions with Kolmogorov-Arnold Network
### Introducing Sparse Convolutional KANs
This project extends the idea of the innovative architecture of Kolmogorov-Arnold Networks (KAN) to sparse convolutions.

view the PyPI [here](https://pypi.org/project/spkan/)

### Authors
This repository was made by:
 - Mellon Zhang | meilongz@gatech.edu | [LinkedIn](https://www.linkedin.com/in/meilongzhang/)

### Credits
This repository builds upon an implementation of Convolutional-KANs which is available [here](https://github.com/AntonioTepsich/Convolutional-KANs).
This repository uses an efficient implementation of KAN which is available [here](https://github.com/Blealtan/efficient-kan).
The original implementation of KAN is available [here](https://github.com/KindXiaoming/pykan). 
The original paper of the KAN is available [here](https://arxiv.org/pdf/2404.19756).

# Installation
To use as package: 
currently compatible with:
Python: 3.7/3.8/3.9
CUDA: 11.3/11.8


```bash
pip install spkan
```

To edit: 
Use python==3.9 torch>=2.3.0 and spconv-cu118

```bash
git clone https://github.com/meilongzhang/spkan.git
```
